#include "cuetrackwidget.h"
#include <QSplitter>

CueTrackWidget::CueTrackWidget(QWidget *parent) : QWidget(parent) {
    setupUi();
}

void CueTrackWidget::setupUi() {
    QVBoxLayout *layout = new QVBoxLayout(this);

    QSplitter *row = new QSplitter(Qt::Horizontal);
    active = new QCheckBox(this);
    row->addWidget(active);

    userNumberSpin = new QSpinBox(this);
    userNumberSpin->setRange(0, 1000);
    userNumberSpin->setToolTip("Cue user number");
    row->addWidget(userNumberSpin);

    nameEdit = new QLineEdit(this);
    nameEdit->setToolTip("Cue Name");
    row->addWidget(nameEdit);

    descriptionEdit = new QLineEdit(this);
    descriptionEdit->setToolTip("Cue Notes");
    row->addWidget(descriptionEdit);

    filePathEdit = new QLineEdit(this);
    filePathEdit->setToolTip("File name");
    row->addWidget(filePathEdit);

    layout->addWidget(row);

    row = new QSplitter(Qt::Horizontal);
    volumeSpin = new QSpinBox(this);
    volumeSpin->setRange(0, 65535);
    volumeSpin->setToolTip("Volume");
    volumeSpin->setValue(100);
    row->addWidget(volumeSpin);

    bus1Spin = new QSpinBox(this);
    bus1Spin->setRange(0, 255);
    bus1Spin->setToolTip("Bus 1");
    bus1Spin->setValue(255);
    row->addWidget(bus1Spin);

    bus2Spin = new QSpinBox(this);
    bus2Spin->setRange(0, 255);
    bus2Spin->setToolTip("Bus 2");
    bus2Spin->setValue(255);
    row->addWidget(bus2Spin);

    panSpin = new QSpinBox(this);
    panSpin->setRange(0, 255);
    panSpin->setToolTip("Pan");
    panSpin->setValue(128);
    row->addWidget(panSpin);

	pitchSpin = new QSpinBox(this);
    pitchSpin->setRange(0, 255);
    pitchSpin->setToolTip("Pitch");
    pitchSpin->setValue(128);
    row->addWidget(pitchSpin);

    entryPointSpin = new QSpinBox(this);
    entryPointSpin->setRange(0, 255);
    entryPointSpin->setToolTip("Entry Point");
    row->addWidget(entryPointSpin);

    exitPointSpin = new QSpinBox(this);
    exitPointSpin->setRange(0, 255);
    exitPointSpin->setToolTip("Exit Point");
    exitPointSpin->setValue(255);
    row->addWidget(exitPointSpin);

    layout->addWidget(row);

    row = new QSplitter(Qt::Horizontal);
	setupStatusCombo();
    statusCombo->setToolTip("Playback Status");
    row->addWidget(statusCombo);

    fadeInSpin = new QSpinBox(this);
    fadeInSpin->setRange(0, 10000);
    fadeInSpin->setToolTip("Fade In Time");
    fadeInSpin->setValue(3);
    row->addWidget(fadeInSpin);

    fadeOutSpin = new QSpinBox(this);
    fadeOutSpin->setRange(0, 10000);
    fadeOutSpin->setToolTip("Fade Out Time");
    fadeOutSpin->setValue(3);
    row->addWidget(fadeOutSpin);

	waitInSpin = new QSpinBox(this);
	waitInSpin->setRange(0, 10000);
    waitInSpin->setToolTip("Wait In Time");
    row->addWidget(waitInSpin);

	waitOutSpin = new QSpinBox(this);
	waitOutSpin->setRange(0, 10000);
    waitOutSpin->setToolTip("Wait Out Time");
    row->addWidget(waitOutSpin);

	stopAtEndCheck = new QCheckBox(this);
    stopAtEndCheck->setToolTip("Halt");
    stopAtEndCheck->setChecked("True");
    row->addWidget(stopAtEndCheck);

    layout->addWidget(row);

	setLayout(layout);
}

QWidget *CueTrackWidget::createHeader()
{
    QWidget *ret = new QWidget();

    auto layout = new QHBoxLayout(this);
    QLabel *l = new QLabel("Cue Number");
    layout->addWidget(l);
    l = new QLabel("File Path");
    layout->addWidget(l);
    l = new QLabel("Volume");
    layout->addWidget(l);
    l = new QLabel("Bus 1");
    layout->addWidget(l);
    l = new QLabel("Bus 2");
    layout->addWidget(l);
    l = new QLabel("Pan");
    layout->addWidget(l);
    l = new QLabel("Pitch");
    layout->addWidget(l);
    l = new QLabel("Playback Status");
    layout->addWidget(l);
    l = new QLabel("Fade In");
    layout->addWidget(l);
    l = new QLabel("Fade Out");
    layout->addWidget(l);
    l = new QLabel("Wait In");
    layout->addWidget(l);
    l = new QLabel("Wait Out ");
    layout->addWidget(l);
    l = new QLabel("Halt");
    layout->addWidget(l);
    l = new QLabel("Name");
    layout->addWidget(l);
    l = new QLabel("Notes");
    layout->addWidget(l);
    l = new QLabel("Entry Point");
    layout->addWidget(l);
    l = new QLabel("Exit Point");
    layout->addWidget(l);
    ret->setLayout(layout);
    return ret;
}

void CueTrackWidget::setupStatusCombo() {
    statusCombo = new QComboBox(this);
    statusCombo->addItem("Stopped", Stopped);
    statusCombo->addItem("Paused", Paused);
	statusCombo->addItem("PlayingOnce", PlayingOnce);
    statusCombo->addItem("PlayingLoop", PlayingLoop);
	statusCombo->addItem("Iddle", Iddle);
	statusCombo->addItem("PlayingFolder", PlayingFolder);
	statusCombo->addItem("PlayingFolderLoop", PlayingFolderLoop);
	statusCombo->addItem("PlayingFolderRandom", PlayingFolderRandom);
}

CueTrack CueTrackWidget::saveCueTrack() const {
    CueTrack cueTrack;
    cueTrack.filePath = filePathEdit->text().toStdString();
    cueTrack.volume = volumeSpin->value();
    // Guarda el resto de los campos aquí...

    cueTrack.status = static_cast<Status>(statusCombo->currentData().toInt());
    return cueTrack;
}
