#ifndef CUETRACKWIDGET_H
#define CUETRACKWIDGET_H

#include <QWidget>
#include <QLineEdit>
#include <QSpinBox>
#include <QComboBox>
#include <QFormLayout>
#include <QCheckBox>
#include <QLabel>
#include "defines.h"

class CueTrackWidget : public QWidget {
    Q_OBJECT

public:
    explicit CueTrackWidget(QWidget *parent = nullptr);

    CueTrack saveCueTrack() const;
    QWidget *createHeader();
	int audioLayer = 0;

	int getVolume() const { return volumeSpin->value(); }
	int getPan() const { return panSpin->value(); }
	int getPitch() const { return pitchSpin->value(); }
	int getBus1() const { return bus1Spin->value(); }
	int getBus2() const { return bus2Spin->value(); }
	Status getStatus() const { return static_cast<Status>(statusCombo->currentIndex()); }
	QString getFilePath() const { return filePathEdit->text(); }
    void setFilePath(QString text) const { filePathEdit->setText(text);};
	int getFadeIn() const { return fadeInSpin->value(); }
	int getFadeOut() const { return fadeOutSpin->value(); }
	int getWaitIn() const { return waitInSpin->value(); }
	int getWaitOut() const { return waitOutSpin->value(); }
	bool getStopAtEnd() const { return stopAtEndCheck->isChecked(); }
	QString getName() const { return nameEdit->text(); }
	QString getDescription() const { return descriptionEdit->text(); }
	int getUserNumber() const { return userNumberSpin->value(); }
	int getEntryPoint() const { return entryPointSpin->value(); }
	int getExitPoint() const { return exitPointSpin->value(); }
	void highlight(bool highlight) {
        if (highlight)
                this->setStyleSheet("background-color: yellow;");
    	else
	        this->setStyleSheet("background-color: white;");
	}

private:
    QCheckBox* active;
    QLineEdit* filePathEdit;
    QSpinBox* volumeSpin;
    QSpinBox* panSpin;
    QSpinBox* pitchSpin;
    QSpinBox* bus1Spin;
    QSpinBox* bus2Spin;
    QComboBox* statusCombo;
    QSpinBox* fadeOutSpin;
    QSpinBox* fadeInSpin;
    QSpinBox* waitInSpin;
    QSpinBox* waitOutSpin;
    QCheckBox* stopAtEndCheck;
    QLineEdit* nameEdit;
    QLineEdit* descriptionEdit;
    QSpinBox* userNumberSpin;
    QSpinBox* entryPointSpin;
    QSpinBox* exitPointSpin;

    void setupUi();
    void setupStatusCombo();
};

#endif // CUETRACKWIDGET_H
